Read Me File for Adobe® OpenType® Fonts

## Adobe® OpenType® Fonts

Thank you for licensing Adobe OpenType fonts. In order to ensure that you have the most up-to-date product information, Adobe has posted an OpenType Read Me file on the Adobe web site that contains information such as minimum system requirements, technical support contact information and software installation notes. We have also posted an OpenType User's Guide in PDF format on the Adobe web site that can be viewed online and downloaded to your computer.

If you have licensed an Adobe OpenType Pro font, there may be additional PDF documents, such as a specimen book, a glyph complement showing, and a typeface-specific Read Me file, available on the typeface’s product pages on the Adobe web site. These additional files may be viewed online or downloaded to your computer.

To get you started quickly, below are links to localized installation instructions for your fonts.

#### Installation Instructions

English
Instructions for installing this font can be found online at http://www.adobe.com/type/browser/fontinstall/instructions_main.html.

French / Français
Le mode d'installation de cette police de caractère se trouve en ligne à http://www.adobe.com/type/browser/fontinstall/instructions_main.html.

German / Deutsch
Die Anweisungen zur Installation dieser Schriftart finden Sie online unter http://www.adobe.com/type/browser/fontinstall/instructions_main.html.

Italian / Italiano
Le istruzioni per l'installazione di questo font sono disponibili online all'indirizzo http://www.adobe.com/type/browser/fontinstall/instructions_main.html.

Spanish / Español
Las instrucciones para instalar esta fuente se pueden encontrar online en http://www.adobe.com/type/browser/fontinstall/instructions_main.html.

Dutch / Hollands
De instructies voor de installatie van dit lettertype vindt u op http://www.adobe.com/type/browser/fontinstall/instructions_main.html.

Swedish / Svenska
Anvisningar för hur det här teckensnittet installeras finns online på http://www.adobe.com/type/browser/fontinstall/instructions_main.html.

Norwegian / Norsk
Instruksjoner for installering av skrifttypen finnes online på http://www.adobe.com/type/browser/fontinstall/instructions_main.html.

Finnish / Suomi
Ohjeet tämän fontin asentamiseen löytyvät osoitteesta http://www.adobe.com/type/browser/fontinstall/instructions_main.html.

Danish / Dansk
Du finder en vejledning i installation af denne skrifttype online på adressen http://www.adobe.com/type/browser/fontinstall/instructions_main.html.

Japanese / 日本語
このフォントをインストールする手順は、オンラインで http://www.adobe.com/type/browser/fontinstall/instructions_main.html を参照してください。